Function get_mode
pub fn get_mode() -> GotModeExpand description
Binding to nvim_get_mode().
Gets the current mode. The blocking field of
GotMode is true if Neovim is waiting for input.
pub fn get_mode() -> GotModeBinding to nvim_get_mode().
Gets the current mode. The blocking field of
GotMode is true if Neovim is waiting for input.