Function strwidth
pub fn strwidth(text: &str) -> Result<usize, Error>Expand description
Binding to nvim_strwidth().
Calculates the number of display cells occupied by text. Control
characters like <Tab> count as one cell.
pub fn strwidth(text: &str) -> Result<usize, Error>Binding to nvim_strwidth().
Calculates the number of display cells occupied by text. Control
characters like <Tab> count as one cell.