SetExtmarkHlGroup

Trait SetExtmarkHlGroup 

pub trait SetExtmarkHlGroup {
    // Required method
    fn into_object(self) -> Object;
}
A trait implemented by types that can be used to specify the highlight group in various methods on the SetExtmarkOptsBuilder.

Required Methods

fn into_object(self) -> Object

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types



impl SetExtmarkHlGroup for &str



fn into_object(self) -> Object



impl SetExtmarkHlGroup for i64



fn into_object(self) -> Object



impl SetExtmarkHlGroup for u32



fn into_object(self) -> Object



impl<T> SetExtmarkHlGroup for Vec<T>
where T: StringOrInt,



fn into_object(self) -> Object

Implementors